==> kubernetes-model-admissionregistration-5.3.0-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/MutatingWebhookFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

public interface MutatingWebhookFluent<A extends MutatingWebhookFluent<A>> extends Fluent<A> {


    public A addToAdmissionReviewVersions(int index,String item);
    public A setToAdmissionReviewVersions(int index,String item);
    public A addToAdmissionReviewVersions(String... items);
    public A addAllToAdmissionReviewVersions(Collection<String> items);
    public A removeFromAdmissionReviewVersions(String... items);
    public A removeAllFromAdmissionReviewVersions(Collection<String> items);
    public List<String> getAdmissionReviewVersions();
    public String getAdmissionReviewVersion(int index);
    public String getFirstAdmissionReviewVersion();
    public String getLastAdmissionReviewVersion();
    public String getMatchingAdmissionReviewVersion(Predicate<String> predicate);
    public Boolean hasMatchingAdmissionReviewVersion(Predicate<String> predicate);
    public A withAdmissionReviewVersions(List<String> admissionReviewVersions);
    public A withAdmissionReviewVersions(String... admissionReviewVersions);
    public Boolean hasAdmissionReviewVersions();
    public A addNewAdmissionReviewVersion(StringBuilder arg1);
    public A addNewAdmissionReviewVersion(int[] arg1,int arg2,int arg3);
    public A addNewAdmissionReviewVersion(char[] arg1);
    public A addNewAdmissionReviewVersion(StringBuffer arg1);
    public A addNewAdmissionReviewVersion(byte[] arg1,int arg2);
    public A addNewAdmissionReviewVersion(byte[] arg1);
    public A addNewAdmissionReviewVersion(char[] arg1,int arg2,int arg3);
    public A addNewAdmissionReviewVersion(byte[] arg1,int arg2,int arg3);
    public A addNewAdmissionReviewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewAdmissionReviewVersion(String arg1);
    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public WebhookClientConfig getClientConfig();
    public WebhookClientConfig buildClientConfig();
    public A withClientConfig(WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public MutatingWebhookFluent.ClientConfigNested<A> withNewClientConfig();
    public MutatingWebhookFluent.ClientConfigNested<A> withNewClientConfigLike(WebhookClientConfig item);
    public MutatingWebhookFluent.ClientConfigNested<A> editClientConfig();
    public MutatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfig();
    public MutatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(WebhookClientConfig item);
    public String getFailurePolicy();
    public A withFailurePolicy(String failurePolicy);
    public Boolean hasFailurePolicy();
    public A withNewFailurePolicy(StringBuilder arg1);
    public A withNewFailurePolicy(int[] arg1,int arg2,int arg3);
    public A withNewFailurePolicy(char[] arg1);
    public A withNewFailurePolicy(StringBuffer arg1);
    public A withNewFailurePolicy(byte[] arg1,int arg2);
    public A withNewFailurePolicy(byte[] arg1);
    public A withNewFailurePolicy(char[] arg1,int arg2,int arg3);
    public A withNewFailurePolicy(byte[] arg1,int arg2,int arg3);
    public A withNewFailurePolicy(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFailurePolicy(String arg1);
    public String getMatchPolicy();
    public A withMatchPolicy(String matchPolicy);
    public Boolean hasMatchPolicy();
    public A withNewMatchPolicy(StringBuilder arg1);
    public A withNewMatchPolicy(int[] arg1,int arg2,int arg3);
    public A withNewMatchPolicy(char[] arg1);
    public A withNewMatchPolicy(StringBuffer arg1);
    public A withNewMatchPolicy(byte[] arg1,int arg2);
    public A withNewMatchPolicy(byte[] arg1);
    public A withNewMatchPolicy(char[] arg1,int arg2,int arg3);
    public A withNewMatchPolicy(byte[] arg1,int arg2,int arg3);
    public A withNewMatchPolicy(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMatchPolicy(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getNamespaceSelector();
    public LabelSelector buildNamespaceSelector();
    public A withNamespaceSelector(LabelSelector namespaceSelector);
    public Boolean hasNamespaceSelector();
    public MutatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
    public MutatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
    public MutatingWebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector();
    public MutatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
    public MutatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildObjectSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getObjectSelector();
    public LabelSelector buildObjectSelector();
    public A withObjectSelector(LabelSelector objectSelector);
    public Boolean hasObjectSelector();
    public MutatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelector();
    public MutatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelectorLike(LabelSelector item);
    public MutatingWebhookFluent.ObjectSelectorNested<A> editObjectSelector();
    public MutatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelector();
    public MutatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelectorLike(LabelSelector item);
    public String getReinvocationPolicy();
    public A withReinvocationPolicy(String reinvocationPolicy);
    public Boolean hasReinvocationPolicy();
    public A withNewReinvocationPolicy(StringBuilder arg1);
    public A withNewReinvocationPolicy(int[] arg1,int arg2,int arg3);
    public A withNewReinvocationPolicy(char[] arg1);
    public A withNewReinvocationPolicy(StringBuffer arg1);
    public A withNewReinvocationPolicy(byte[] arg1,int arg2);
    public A withNewReinvocationPolicy(byte[] arg1);
    public A withNewReinvocationPolicy(char[] arg1,int arg2,int arg3);
    public A withNewReinvocationPolicy(byte[] arg1,int arg2,int arg3);
    public A withNewReinvocationPolicy(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReinvocationPolicy(String arg1);
    public A addToRules(int index,RuleWithOperations item);
    public A setToRules(int index,RuleWithOperations item);
    public A addToRules(RuleWithOperations... items);
    public A addAllToRules(Collection<RuleWithOperations> items);
    public A removeFromRules(RuleWithOperations... items);
    public A removeAllFromRules(Collection<RuleWithOperations> items);
    public A removeMatchingFromRules(Predicate<RuleWithOperationsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<RuleWithOperations> getRules();
    public List<RuleWithOperations> buildRules();
    public RuleWithOperations buildRule(int index);
    public RuleWithOperations buildFirstRule();
    public RuleWithOperations buildLastRule();
    public RuleWithOperations buildMatchingRule(Predicate<RuleWithOperationsBuilder> predicate);
    public Boolean hasMatchingRule(Predicate<RuleWithOperationsBuilder> predicate);
    public A withRules(List<RuleWithOperations> rules);
    public A withRules(RuleWithOperations... rules);
    public Boolean hasRules();
    public MutatingWebhookFluent.RulesNested<A> addNewRule();
    public MutatingWebhookFluent.RulesNested<A> addNewRuleLike(RuleWithOperations item);
    public MutatingWebhookFluent.RulesNested<A> setNewRuleLike(int index,RuleWithOperations item);
    public MutatingWebhookFluent.RulesNested<A> editRule(int index);
    public MutatingWebhookFluent.RulesNested<A> editFirstRule();
    public MutatingWebhookFluent.RulesNested<A> editLastRule();
    public MutatingWebhookFluent.RulesNested<A> editMatchingRule(Predicate<RuleWithOperationsBuilder> predicate);
    public String getSideEffects();
    public A withSideEffects(String sideEffects);
    public Boolean hasSideEffects();
    public A withNewSideEffects(StringBuilder arg1);
    public A withNewSideEffects(int[] arg1,int arg2,int arg3);
    public A withNewSideEffects(char[] arg1);
    public A withNewSideEffects(StringBuffer arg1);
    public A withNewSideEffects(byte[] arg1,int arg2);
    public A withNewSideEffects(byte[] arg1);
    public A withNewSideEffects(char[] arg1,int arg2,int arg3);
    public A withNewSideEffects(byte[] arg1,int arg2,int arg3);
    public A withNewSideEffects(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSideEffects(String arg1);
    public Integer getTimeoutSeconds();
    public A withTimeoutSeconds(Integer timeoutSeconds);
    public Boolean hasTimeoutSeconds();
    public A withNewTimeoutSeconds(int arg1);
    public interface ClientConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,WebhookClientConfigFluent<MutatingWebhookFluent.ClientConfigNested<N>> {

            public N and();
            public N endClientConfig();    }


    public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<MutatingWebhookFluent.NamespaceSelectorNested<N>> {

            public N and();
            public N endNamespaceSelector();    }


    public interface ObjectSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<MutatingWebhookFluent.ObjectSelectorNested<N>> {

            public N and();
            public N endObjectSelector();    }


    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RuleWithOperationsFluent<MutatingWebhookFluent.RulesNested<N>> {

            public N and();
            public N endRule();    }


}

==> kubernetes-model-admissionregistration-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/admissionregistration/v1/MutatingWebhookFluent.java <==
package io.fabric8.kubernetes.api.model.admissionregistration.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import java.lang.StringBuilder;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.lang.StringBuffer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

public interface MutatingWebhookFluent<A extends MutatingWebhookFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    public A addToAdmissionReviewVersions(int index,String item);
    public A setToAdmissionReviewVersions(int index,String item);
    public A addToAdmissionReviewVersions(String... items);
    public A addAllToAdmissionReviewVersions(Collection<String> items);
    public A removeFromAdmissionReviewVersions(String... items);
    public A removeAllFromAdmissionReviewVersions(Collection<String> items);
    public List<String> getAdmissionReviewVersions();
    public String getAdmissionReviewVersion(int index);
    public String getFirstAdmissionReviewVersion();
    public String getLastAdmissionReviewVersion();
    public String getMatchingAdmissionReviewVersion(Predicate<String> predicate);
    public Boolean hasMatchingAdmissionReviewVersion(Predicate<String> predicate);
    public A withAdmissionReviewVersions(List<String> admissionReviewVersions);
    public A withAdmissionReviewVersions(String... admissionReviewVersions);
    public Boolean hasAdmissionReviewVersions();
    public A addNewAdmissionReviewVersion(StringBuilder arg1);
    public A addNewAdmissionReviewVersion(int[] arg1,int arg2,int arg3);
    public A addNewAdmissionReviewVersion(char[] arg1);
    public A addNewAdmissionReviewVersion(StringBuffer arg1);
    public A addNewAdmissionReviewVersion(byte[] arg1,int arg2);
    public A addNewAdmissionReviewVersion(byte[] arg1);
    public A addNewAdmissionReviewVersion(char[] arg1,int arg2,int arg3);
    public A addNewAdmissionReviewVersion(byte[] arg1,int arg2,int arg3);
    public A addNewAdmissionReviewVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A addNewAdmissionReviewVersion(String arg1);
    
/**
 * This method has been deprecated, please use method buildClientConfig instead.
 * @return The buildable object.
 */
@Deprecated public WebhookClientConfig getClientConfig();
    public WebhookClientConfig buildClientConfig();
    public A withClientConfig(WebhookClientConfig clientConfig);
    public Boolean hasClientConfig();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ClientConfigNested<A> withNewClientConfig();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ClientConfigNested<A> withNewClientConfigLike(WebhookClientConfig item);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ClientConfigNested<A> editClientConfig();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfig();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ClientConfigNested<A> editOrNewClientConfigLike(WebhookClientConfig item);
    public String getFailurePolicy();
    public A withFailurePolicy(String failurePolicy);
    public Boolean hasFailurePolicy();
    public A withNewFailurePolicy(StringBuilder arg1);
    public A withNewFailurePolicy(int[] arg1,int arg2,int arg3);
    public A withNewFailurePolicy(char[] arg1);
    public A withNewFailurePolicy(StringBuffer arg1);
    public A withNewFailurePolicy(byte[] arg1,int arg2);
    public A withNewFailurePolicy(byte[] arg1);
    public A withNewFailurePolicy(char[] arg1,int arg2,int arg3);
    public A withNewFailurePolicy(byte[] arg1,int arg2,int arg3);
    public A withNewFailurePolicy(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewFailurePolicy(String arg1);
    public String getMatchPolicy();
    public A withMatchPolicy(String matchPolicy);
    public Boolean hasMatchPolicy();
    public A withNewMatchPolicy(StringBuilder arg1);
    public A withNewMatchPolicy(int[] arg1,int arg2,int arg3);
    public A withNewMatchPolicy(char[] arg1);
    public A withNewMatchPolicy(StringBuffer arg1);
    public A withNewMatchPolicy(byte[] arg1,int arg2);
    public A withNewMatchPolicy(byte[] arg1);
    public A withNewMatchPolicy(char[] arg1,int arg2,int arg3);
    public A withNewMatchPolicy(byte[] arg1,int arg2,int arg3);
    public A withNewMatchPolicy(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewMatchPolicy(String arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(StringBuilder arg1);
    public A withNewName(int[] arg1,int arg2,int arg3);
    public A withNewName(char[] arg1);
    public A withNewName(StringBuffer arg1);
    public A withNewName(byte[] arg1,int arg2);
    public A withNewName(byte[] arg1);
    public A withNewName(char[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3);
    public A withNewName(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewName(String arg1);
    
/**
 * This method has been deprecated, please use method buildNamespaceSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getNamespaceSelector();
    public LabelSelector buildNamespaceSelector();
    public A withNamespaceSelector(LabelSelector namespaceSelector);
    public Boolean hasNamespaceSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.NamespaceSelectorNested<A> withNewNamespaceSelectorLike(LabelSelector item);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.NamespaceSelectorNested<A> editNamespaceSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.NamespaceSelectorNested<A> editOrNewNamespaceSelectorLike(LabelSelector item);
    
/**
 * This method has been deprecated, please use method buildObjectSelector instead.
 * @return The buildable object.
 */
@Deprecated public LabelSelector getObjectSelector();
    public LabelSelector buildObjectSelector();
    public A withObjectSelector(LabelSelector objectSelector);
    public Boolean hasObjectSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ObjectSelectorNested<A> withNewObjectSelectorLike(LabelSelector item);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ObjectSelectorNested<A> editObjectSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelector();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ObjectSelectorNested<A> editOrNewObjectSelectorLike(LabelSelector item);
    public String getReinvocationPolicy();
    public A withReinvocationPolicy(String reinvocationPolicy);
    public Boolean hasReinvocationPolicy();
    public A withNewReinvocationPolicy(StringBuilder arg1);
    public A withNewReinvocationPolicy(int[] arg1,int arg2,int arg3);
    public A withNewReinvocationPolicy(char[] arg1);
    public A withNewReinvocationPolicy(StringBuffer arg1);
    public A withNewReinvocationPolicy(byte[] arg1,int arg2);
    public A withNewReinvocationPolicy(byte[] arg1);
    public A withNewReinvocationPolicy(char[] arg1,int arg2,int arg3);
    public A withNewReinvocationPolicy(byte[] arg1,int arg2,int arg3);
    public A withNewReinvocationPolicy(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewReinvocationPolicy(String arg1);
    public A addToRules(int index,RuleWithOperations item);
    public A setToRules(int index,RuleWithOperations item);
    public A addToRules(RuleWithOperations... items);
    public A addAllToRules(Collection<RuleWithOperations> items);
    public A removeFromRules(RuleWithOperations... items);
    public A removeAllFromRules(Collection<RuleWithOperations> items);
    public A removeMatchingFromRules(Predicate<RuleWithOperationsBuilder> predicate);
    
/**
 * This method has been deprecated, please use method buildRules instead.
 * @return The buildable object.
 */
@Deprecated public List<RuleWithOperations> getRules();
    public List<RuleWithOperations> buildRules();
    public RuleWithOperations buildRule(int index);
    public RuleWithOperations buildFirstRule();
    public RuleWithOperations buildLastRule();
    public RuleWithOperations buildMatchingRule(Predicate<RuleWithOperationsBuilder> predicate);
    public Boolean hasMatchingRule(Predicate<RuleWithOperationsBuilder> predicate);
    public A withRules(List<RuleWithOperations> rules);
    public A withRules(RuleWithOperations... rules);
    public Boolean hasRules();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> addNewRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> addNewRuleLike(RuleWithOperations item);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> setNewRuleLike(int index,RuleWithOperations item);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> editRule(int index);
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> editFirstRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> editLastRule();
    public io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<A> editMatchingRule(Predicate<RuleWithOperationsBuilder> predicate);
    public String getSideEffects();
    public A withSideEffects(String sideEffects);
    public Boolean hasSideEffects();
    public A withNewSideEffects(StringBuilder arg1);
    public A withNewSideEffects(int[] arg1,int arg2,int arg3);
    public A withNewSideEffects(char[] arg1);
    public A withNewSideEffects(StringBuffer arg1);
    public A withNewSideEffects(byte[] arg1,int arg2);
    public A withNewSideEffects(byte[] arg1);
    public A withNewSideEffects(char[] arg1,int arg2,int arg3);
    public A withNewSideEffects(byte[] arg1,int arg2,int arg3);
    public A withNewSideEffects(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewSideEffects(String arg1);
    public Integer getTimeoutSeconds();
    public A withTimeoutSeconds(Integer timeoutSeconds);
    public Boolean hasTimeoutSeconds();
    public A withNewTimeoutSeconds(int arg0);
    public interface ClientConfigNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,WebhookClientConfigFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ClientConfigNested<N>> {

            public N and();
            public N endClientConfig();    }


    public interface NamespaceSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.NamespaceSelectorNested<N>> {

            public N and();
            public N endNamespaceSelector();    }


    public interface ObjectSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,LabelSelectorFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.ObjectSelectorNested<N>> {

            public N and();
            public N endObjectSelector();    }


    public interface RulesNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,RuleWithOperationsFluent<io.fabric8.kubernetes.api.model.admissionregistration.v1.MutatingWebhookFluent.RulesNested<N>> {

            public N and();
            public N endRule();    }


}
